@@ -678,6 +678,39 @@ class AuditApplyClientResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ClientBaseElem(AbstractModel):
+    """代客基础信息，for国际站查代客API
+
+    """
+
+    def __init__(self):
+        """
+        :param AgentUin: 代客关联的代理商UIN
+        :type AgentUin: str
+        :param ClientUin: 代客UIN
+        :type ClientUin: str
+        :param ClientRelateType: 代客关联类型 0:代理 1:转售
+        :type ClientRelateType: int
+        :param AgentCooperationMode: 代理商合作模式 0:代理 1:转售
+        :type AgentCooperationMode: int
+        :param AgentCountry: 代理商国家编码 China:中国  其他:海外，如US等
+        :type AgentCountry: str
+        """
+        self.AgentUin = None
+        self.ClientUin = None
+        self.ClientRelateType = None
+        self.AgentCooperationMode = None
+        self.AgentCountry = None
+
+
+    def _deserialize(self, params):
+        self.AgentUin = params.get("AgentUin")
+        self.ClientUin = params.get("ClientUin")
+        self.ClientRelateType = params.get("ClientRelateType")
+        self.AgentCooperationMode = params.get("AgentCooperationMode")
+        self.AgentCountry = params.get("AgentCountry")
+
+
 class CreatePayRelationForClientRequest(AbstractModel):
     """CreatePayRelationForClient请求参数结构体
 
@@ -1270,6 +1303,81 @@ class DescribeAgentPayDealsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAgentPayDealsV2Request(AbstractModel):
+    """DescribeAgentPayDealsV2请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Offset: 偏移量
+        :type Offset: int
+        :param Limit: 限制数目
+        :type Limit: int
+        :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
+        :type CreatTimeRangeStart: str
+        :param CreatTimeRangeEnd: 下单时间范围终止点
+        :type CreatTimeRangeEnd: str
+        :param Order: 0:下单时间降序；其他：下单时间升序
+        :type Order: int
+        :param Status: 订单的状态(1：未支付;2：已支付;3：发货中;4：已发货;5：发货失败;6：已退款;7：已关单;8：订单过期;9：订单已失效;10：产品已失效;11：代付拒绝;12：支付中)
+        :type Status: int
+        :param OwnerUins: 下单人账号ID列表
+        :type OwnerUins: list of str
+        :param DealNames: 订单号列表
+        :type DealNames: list of str
+        """
+        self.Offset = None
+        self.Limit = None
+        self.CreatTimeRangeStart = None
+        self.CreatTimeRangeEnd = None
+        self.Order = None
+        self.Status = None
+        self.OwnerUins = None
+        self.DealNames = None
+
+
+    def _deserialize(self, params):
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        self.CreatTimeRangeStart = params.get("CreatTimeRangeStart")
+        self.CreatTimeRangeEnd = params.get("CreatTimeRangeEnd")
+        self.Order = params.get("Order")
+        self.Status = params.get("Status")
+        self.OwnerUins = params.get("OwnerUins")
+        self.DealNames = params.get("DealNames")
+
+
+class DescribeAgentPayDealsV2Response(AbstractModel):
+    """DescribeAgentPayDealsV2返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AgentPayDealSet: 订单数组
+        :type AgentPayDealSet: list of AgentDealNewElem
+        :param TotalCount: 符合条件的订单总数量
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.AgentPayDealSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("AgentPayDealSet") is not None:
+            self.AgentPayDealSet = []
+            for item in params.get("AgentPayDealSet"):
+                obj = AgentDealNewElem()
+                obj._deserialize(item)
+                self.AgentPayDealSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeAgentSelfPayDealsRequest(AbstractModel):
     """DescribeAgentSelfPayDeals请求参数结构体
 
@@ -1345,6 +1453,81 @@ class DescribeAgentSelfPayDealsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAgentSelfPayDealsV2Request(AbstractModel):
+    """DescribeAgentSelfPayDealsV2请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param OwnerUin: 下单人账号ID
+        :type OwnerUin: str
+        :param Offset: 偏移量
+        :type Offset: int
+        :param Limit: 限制数目
+        :type Limit: int
+        :param CreatTimeRangeStart: 下单时间范围起始点(不传时会默认查15天内订单，传值时需要传15天内的起始时间)
+        :type CreatTimeRangeStart: str
+        :param CreatTimeRangeEnd: 下单时间范围终止点
+        :type CreatTimeRangeEnd: str
+        :param Order: 0:下单时间降序；其他：下单时间升序
+        :type Order: int
+        :param Status: 订单的状态(1：未支付;2：已支付;3：发货中;4：已发货;5：发货失败;6：已退款;7：已关单;8：订单过期;9：订单已失效;10：产品已失效;11：代付拒绝;12：支付中)
+        :type Status: int
+        :param DealNames: 订单号列表
+        :type DealNames: list of str
+        """
+        self.OwnerUin = None
+        self.Offset = None
+        self.Limit = None
+        self.CreatTimeRangeStart = None
+        self.CreatTimeRangeEnd = None
+        self.Order = None
+        self.Status = None
+        self.DealNames = None
+
+
+    def _deserialize(self, params):
+        self.OwnerUin = params.get("OwnerUin")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        self.CreatTimeRangeStart = params.get("CreatTimeRangeStart")
+        self.CreatTimeRangeEnd = params.get("CreatTimeRangeEnd")
+        self.Order = params.get("Order")
+        self.Status = params.get("Status")
+        self.DealNames = params.get("DealNames")
+
+
+class DescribeAgentSelfPayDealsV2Response(AbstractModel):
+    """DescribeAgentSelfPayDealsV2返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AgentPayDealSet: 订单数组
+        :type AgentPayDealSet: list of AgentDealNewElem
+        :param TotalCount: 符合条件的订单总数量
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.AgentPayDealSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("AgentPayDealSet") is not None:
+            self.AgentPayDealSet = []
+            for item in params.get("AgentPayDealSet"):
+                obj = AgentDealNewElem()
+                obj._deserialize(item)
+                self.AgentPayDealSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeClientBalanceRequest(AbstractModel):
     """DescribeClientBalance请求参数结构体
 
@@ -1369,17 +1552,68 @@ class DescribeClientBalanceResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Balance: 账户余额，单位分
+        :param Balance: 账户可用余额，单位分 （可用余额 = 现金余额 - 冻结金额）
         :type Balance: int
+        :param Cash: 账户现金余额，单位分
+        :type Cash: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.Balance = None
+        self.Cash = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.Balance = params.get("Balance")
+        self.Cash = params.get("Cash")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeClientBaseInfoRequest(AbstractModel):
+    """DescribeClientBaseInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ClientUin: 代客UIN
+        :type ClientUin: str
+        """
+        self.ClientUin = None
+
+
+    def _deserialize(self, params):
+        self.ClientUin = params.get("ClientUin")
+
+
+class DescribeClientBaseInfoResponse(AbstractModel):
+    """DescribeClientBaseInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ClientBaseSet: 代客基础信息数组
+        :type ClientBaseSet: list of ClientBaseElem
+        :param TotalCount: 符合条件的代客数
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ClientBaseSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ClientBaseSet") is not None:
+            self.ClientBaseSet = []
+            for item in params.get("ClientBaseSet"):
+                obj = ClientBaseElem()
+                obj._deserialize(item)
+                self.ClientBaseSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
 
 
