@@ -400,12 +400,17 @@ class DescribeQualityMetricsRequest(AbstractModel):
         :param EndTime: 结束时间，Unix时间戳，单位秒，时间跨度不能超过7天
         :type EndTime: int
         :param Metric: 查询的指标，目前支持以下值
-  - image_load_total_count: 图片加载总数
-  - image_load_fail_count: 图片加载失败数量
-  - image_load_success_rate: 图片加载成功率
-  - ppt_load_total_count: PPT加载总数
-  - ppt_load_fail_count: PPT加载失败总数
-  - ppt_load_success_rate: PPT加载成功率
+  - image_load_total_count: 图片加载总数（单位，次）
+  - image_load_fail_count: 图片加载失败数量（单位，次）
+  - image_load_success_rate: 图片加载成功率（百分比）
+  - ppt_load_total_count: PPT加载总数（单位，次）
+  - ppt_load_fail_count: PPT加载失败总数（单位，次）
+  - ppt_load_success_rate: PPT加载成功率（单位，百分比）
+  - verify_sdk_total_count: 白板鉴权总次数（单位，次）
+  - verify_sdk_fail_count: 白板鉴权失败次数（单位，次）
+  - verify_sdk_success_rate: 白板鉴权成功率（单位，百分比）
+  - verify_sdk_in_one_second_rate: 白板鉴权秒开率（单位，百分比）
+  - verify_sdk_cost_avg: 白板鉴权耗时平均时间（单位，毫秒）
         :type Metric: str
         :param Interval: 聚合的时间维度，目前只支持1小时，输入值为"1h"
         :type Interval: str
@@ -1501,7 +1506,7 @@ class StartWhiteboardPushRequest(AbstractModel):
         :type PushUserSig: str
         :param Whiteboard: 白板参数，例如白板宽高、背景颜色等
         :type Whiteboard: :class:`tencentcloud.tiw.v20190919.models.Whiteboard`
-        :param AutoStopTimeout: 自动停止推流超时时间，单位秒，取值范围[300, 259200], 默认值为1800秒。
+        :param AutoStopTimeout: 自动停止推流超时时间，单位秒，取值范围[300, 43200], 默认值为1800秒。
 
 当白板超过设定时间没有操作的时候，白板推流服务会自动停止白板推流。
         :type AutoStopTimeout: int
